.. _user_guides:

User Guides
===========

The User Guides section covers different topics about Orion usage:

.. toctree::
    :maxdepth: 3

    data
    primitives_pipelines/index
    evaluation_doc
    benchmarking
    system/index